# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/spell/spell/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Spell\\Spell\\": "packages/spell/spell/src",
            "Spell\\Spell\\Seeders\\": "packages/spell/spell/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Spell\Spell\Providers\SpellServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Spell'  => Spell\Spell\Facades\Spell::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Spell\\Spell\\Seeders\\SpellTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Spell\Spell\Providers\SpellServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Spell\Spell\Providers\SpellServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Spell\Spell\Providers\SpellServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/spell/{modulename}

**User**

    http://path-to-route-folder/user/spell/{modulename}

**Public**

    http://path-to-route-folder/spells


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/spell/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/spell/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/spell/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/spell/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/spell/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/spell/{modulename}/{slug}
    METHOD: GET